@@ -126,14 +126,10 @@ getPkgData <- function(){
          list(times = as.POSIXct(c('2000-01-01 00:00:00','2001-01-01 00:00:00')),
               url = 'http://thredds.daac.ornl.gov/thredds/dodsC/daymet-agg/daymet-agg.ncml',
               variables = 'prcp'),
-       'gldas' = 
-         list(times = as.POSIXct(c('2010-01-01 00:00:00','2010-01-02 00:00:00')),
-              url = 'dods://hydro1.sci.gsfc.nasa.gov/dods/GLDAS_NOAH10_3H.020',
-              variables = 'avgsurftsfc'),
-       'nldas' = 
-         list(times = as.POSIXct(c('2010-01-01 00:00:00','2010-01-02 00:00:00')),
-              url = 'dods://hydro1.sci.gsfc.nasa.gov/dods/NLDAS_FORA0125_H.002',
-              variables = 'tmp2m'),
+       'stageiv' = 
+         list(times = as.POSIXct(c('2010-01-01 00:00:00','2010-01-05 00:00:00')),
+              url = 'dods://cida.usgs.gov/thredds/dodsC/stageiv_combined',
+              variables = "Total_precipitation_surface_1_Hour_Accumulation"),
        'topowx' = 
          list(times = as.POSIXct(c('2010-01-01 00:00:00','2010-02-01 00:00:00')),
               url = 'http://cida.usgs.gov/thredds/dodsC/topowx',
